package com.muyu.rule.server.controller;

import com.muyu.common.core.domain.Result;

import com.muyu.rule.common.domain.EtlRule;
import com.muyu.rule.common.domain.req.EtlRuleAddReq;
import com.muyu.rule.common.domain.req.EtlRuleListReq;
import com.muyu.rule.common.domain.req.EtlRuleUpdReq;
import com.muyu.rule.common.domain.resp.EtlRuleResp;
import com.muyu.rule.server.service.EtlRuleService;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author：张承志
 * @Package：com.muyu.etl.controller
 * @Project：cloud-etl
 * @name：EtlRuleController
 * @Date：2024/8/21 14:17
 */
@Log4j2
@RestController
@RequestMapping("/etlRule")
@RequiredArgsConstructor
@Tag(name = "etl规则控制层", description = "进行etl规则管理,查看等相关操作")
public class EtlRuleController {

    @Autowired
    private EtlRuleService etlRuleService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @GetMapping("/{id}")
    public Result<EtlRule> queryById(@PathVariable("id") int id){
        EtlRule etlRule = etlRuleService.queryById(id);
        return Result.success(etlRule);
    }


    @PostMapping("/List")
    public Result<List<EtlRuleResp>>  selectList(@Validated @RequestBody EtlRuleListReq req){

     List<EtlRuleResp> list = etlRuleService.selectList(req);

        return Result.success(list);
    }


    /**
     * 新增数据
     *
     * @param etlRule 实例对象
     * @return 实例对象
     */

    @PostMapping
    public Result<EtlRule> add(@RequestBody EtlRuleAddReq etlRule){
        etlRuleService.save(EtlRule.addBuild(etlRule));
        return Result.success();
    }

    /**
     * 更新数据
     *
     * @param etlRule 实例对象
     * @return 实例对象
     */

    @PutMapping("/{id}")
    public Result<EtlRule> edit(@PathVariable("id") Long  id, @RequestBody @Validated EtlRuleUpdReq etlRule){
        etlRuleService.updateById(EtlRule.updBuild(etlRule,()->id));
        return Result.success();
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @DeleteMapping
    public Result<Boolean> deleteById(int id){
        etlRuleService.deleteById(id);
        return Result.success();
    }





}






