package com.muyu.rule.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.rule.common.domain.EtlRule;
import com.muyu.rule.common.domain.req.EtlRuleListReq;
import com.muyu.rule.common.domain.resp.EtlRuleResp;
import com.muyu.rule.server.mapper.EtlRuleMapper;
import com.muyu.rule.server.service.EtlRuleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author：张承志
 * @Package：com.muyu.etl.service.impl
 * @Project：cloud-etl
 * @name：EtlRuleServiceImpl
 * @Date：2024/8/21 14:22
 */
@Service
public class EtlRuleServiceImpl extends ServiceImpl<EtlRuleMapper, EtlRule>  implements EtlRuleService {

    @Autowired
    private EtlRuleMapper etlRuleMapper;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public EtlRule queryById(int id){
        return etlRuleMapper.selectById(id);
    }



    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(int id){
        int total = etlRuleMapper.deleteById(id);
        return total > 0;
    }

    @Override
    public List<EtlRuleResp> selectList(EtlRuleListReq req) {

        LambdaQueryWrapper<EtlRule> queryWrapper = new LambdaQueryWrapper<>();

        queryWrapper.like(StringUtils.isNotEmpty(req.getName()),EtlRule::getName,req.getName());

        queryWrapper.eq(
          StringUtils.isNotEmpty(req.getStatus()),EtlRule::getStatus,req.getStatus()
        );
        queryWrapper.eq(
                StringUtils.isNotEmpty(req.getOpen()),EtlRule::getOpen,req.getOpen()
        );

        queryWrapper.eq(
                StringUtils.isNotEmpty(req.getType()),EtlRule::getType,req.getType()
        );

        List<EtlRule> etlRuleList = this.list(queryWrapper);

        List<EtlRuleResp> respList = etlRuleList.stream()
                .map(etlRule -> EtlRuleResp.etlRuleRespBuilder(etlRule)).toList();


        return respList;
    }













}
